/*
 *  Copyright (c) 2005 Boudewijn Rempt (boud@valdyas.org)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef WET_STICKY_PLUGIN_H_
#define WET_STICKY_PLUGIN_H_

#include <tdeparts/plugin.h>

/**
 * A plugin wrapper around the Wet & Sticky colour space strategy.
 *
 * The Wet & Sticky paint system was first designed in 1991 by Tunde Cockshott
 * and was further developed by David England and Kevin Waite. It was released
 * under the GPL in 2005.
 *
 */
class WetStickyPlugin : public KParts::Plugin
{
    Q_OBJECT
  
public:
    WetStickyPlugin(TQObject *parent, const char *name, const TQStringList &);
    virtual ~WetStickyPlugin();

};

#endif // WET_STICKY_PLUGIN_H_
